
# Slot: deprecated


Description of why and when this element will no longer be used

URI: [linkml:deprecated](https://w3id.org/linkml/deprecated)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [CommonMetadata](CommonMetadata.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [PermissibleValue](PermissibleValue.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
